package com.cf.cs.authentication.misc;

import com.cf.cs.base.common.CommonEnumHandler;
import com.cf.cs.base.common.ErrorCode;
import com.cf.cs.database.service.OperationLogDataBaseService;
import com.cf.cs.protocol.misc.ProtocolJsonUtils;
import com.cf.cs.protocol.pojo.po.BaseRespStatus;
import com.cf.cs.protocol.pojo.vo.ProtocolResp;
import jakarta.servlet.ServletOutputStream;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;

import java.io.IOException;

/**
 * The type Security response utils.
 *
 * @author xajhuang @163.com
 */
public class SecurityResponseUtils {
    private SecurityResponseUtils() {
        throw new AssertionError("Instantiating utility class.");
    }

    /**
     * Authentication response.
     *
     * @param request    the request
     * @param response   the response
     * @param error      the error
     * @param readme     the readme
     * @param logService the log service
     * @throws IOException the io exception
     */
    public static void authenticationResponse(HttpServletRequest request,
                                              HttpServletResponse response,
                                              ErrorCode error,
                                              String readme, OperationLogDataBaseService logService) throws IOException {
        response.setContentType("application/json;charset=UTF-8");
        ServletOutputStream          outputStream = response.getOutputStream();
        ProtocolResp<BaseRespStatus> ret          = ProtocolResp.result(error);

        if (logService != null) {
            logService.securityOperationLog(request, ret, error, readme);
        }

        outputStream.write(ProtocolJsonUtils.getJsonBytes(ret));
        outputStream.flush();
        outputStream.close();
    }

    /**
     * Authentication response.
     *
     * @param <T>        the type parameter
     * @param request    the request
     * @param response   the response
     * @param rsp        the rsp
     * @param readme     the readme
     * @param logService the log service
     * @throws IOException the io exception
     */
    public static <T extends BaseRespStatus> void authenticationResponse(HttpServletRequest request,
                                                                         HttpServletResponse response,
                                                                         T rsp,
                                                                         String readme,
                                                                         OperationLogDataBaseService logService) throws IOException {
        response.setContentType("application/json;charset=UTF-8");
        ServletOutputStream          outputStream = response.getOutputStream();
        ProtocolResp<BaseRespStatus> ret          = ProtocolResp.result(ErrorCode.ERR_OK);

        if (logService != null) {
            logService.securityOperationLog(request, ret, CommonEnumHandler.codeOf(ErrorCode.class, rsp.getStatus()), readme);
        }

        outputStream.write(ProtocolJsonUtils.getJsonBytes(ProtocolResp.result(rsp)));
        outputStream.flush();
        outputStream.close();
    }
}
