package com.cf.cs.authentication.security.impl;

import com.cf.cs.authentication.misc.SecurityResponseUtils;
import com.cf.cs.authentication.service.AccountJwtCacheService;
import com.cf.cs.base.common.ErrorCode;
import com.cf.cs.base.misc.ApiContextUtils;
import com.cf.cs.base.misc.HelperUtils;
import com.cf.cs.base.pojo.po.ApiContext;
import com.cf.cs.database.service.OperationLogDataBaseService;
import com.cf.cs.protocol.pojo.vo.LogoutResp;
import jakarta.annotation.Resource;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;
import org.springframework.security.authentication.AuthenticationServiceException;
import org.springframework.security.core.Authentication;
import org.springframework.security.web.authentication.logout.LogoutHandler;
import org.springframework.stereotype.Component;

import java.io.IOException;
import java.util.Arrays;

/**
 * The type Jwt logout handler.
 *
 * @author xajhuang @163.com
 */
@Component
public class JwtLogoutHandler implements LogoutHandler {
    @Resource
    private OperationLogDataBaseService optLogDbService;

    @Resource
    private AccountJwtCacheService accountJwtCacheService;

    @Override
    public void logout(HttpServletRequest request, HttpServletResponse response, Authentication authentication) {
        LogoutResp rsp = new LogoutResp();
        response.setStatus(HttpServletResponse.SC_UNAUTHORIZED);

        try {
            ApiContext ctx      = ApiContextUtils.get();
            String     username = ctx.getUsername();

            if (!HelperUtils.stringNotEmptyOrNull(username)) {
                rsp.setStatus(ErrorCode.ERR_TOKENNOTFOUND.getCode());
                rsp.setMessage(new String[] {ErrorCode.ERR_TOKENNOTFOUND.getDescription()});
            } else {
                // 校验通过，才会执行业务逻辑处理
                accountJwtCacheService.deleteAccountJwtCache(ctx.getUid());
                rsp.setStatus(ErrorCode.ERR_OK.getCode());
                rsp.setMessage(new String[] {ErrorCode.ERR_OK.getDescription()});
            }
            rsp.setUsername(username);

            SecurityResponseUtils.authenticationResponse(request, response, rsp, Arrays.toString(rsp.getMessage()),
                                                         optLogDbService);
        } catch (IOException e) {
            throw new AuthenticationServiceException(e.getMessage());
        }
    }
}
