package com.cf.cs.authentication.service.impl;

import com.cf.cs.authentication.pojo.po.AuthAccountUser;
import com.cf.cs.authentication.service.AuthUsersService;
import com.cf.cs.base.common.CommonStatus;
import com.cf.cs.database.mapper.RoleMapper;
import com.cf.cs.database.pojo.entity.Role;
import com.cf.cs.database.pojo.entity.User;
import com.cf.cs.database.pojo.entity.UserCredential;
import com.cf.cs.database.service.UserDataBaseService;
import jakarta.annotation.Resource;
import lombok.extern.slf4j.Slf4j;
import org.springframework.cache.annotation.CacheEvict;
import org.springframework.cache.annotation.Cacheable;
import org.springframework.stereotype.Service;

/**
 * The type Auth users cache service.
 *
 * @author xajhuang @163.com
 */
@Service
@Slf4j
public class AuthUsersCacheServiceImpl implements AuthUsersService {
    @Resource
    private UserDataBaseService userDbService;

    @Resource
    private RoleMapper roleMapper;

    @Override
    @Cacheable(value = "AUTH_CACHE", key = "'user'+#username", sync = true)
    public AuthAccountUser getAuthAccountByUserName(String username) {
        User user = userDbService.getAccountUserByName(username);

        if (user == null) {
            return null;
        }

        Role role = roleMapper.selectOneById(user.getRoleId());

        if (role == null) {
            return null;
        }

        UserCredential uc = user.getUserCredential();

        return AuthAccountUser.builder()
                              .userName(user.getUsername())
                              .password(uc.getCredential())
                              .authTimeStamp(System.currentTimeMillis())
                              .id(user.getId())
                              .uid(user.getUid())
                              .role(role)
                              //.authorities(getUserAuthority(uc.getUserId()))
                              .accountNonExpired(true)
                              .accountNonLocked(!uc.getState().equals(CommonStatus.LOCKED.getValue()))
                              .credentialsNonExpired(true)
                              .enabled(uc.getState().equals(CommonStatus.NORMAL.getValue()))
                              .build();
    }

    @Override
    @CacheEvict(value = "AUTH_CACHE", key = "'user'+#username")
    public void removeUserByUserName(String username) {
        // Automatic manager by cache
    }
}
