package com.cf.cs.base.common;

import java.util.Arrays;
import java.util.List;

/**
 * The type Common enum handler.
 *
 * @param <E> the type parameter
 * @author xajhuang @163.com
 */
@SuppressWarnings("java:S1068")
public final class CommonEnumHandler<E extends BaseEnum> {
    private final Class<E> enumType;
    private final List<E>  enums;

    /**
     * Instantiates a new Common enum handler.
     *
     * @param type the type
     */
    public CommonEnumHandler(Class<E> type) {
        if (type == null) {
            throw new IllegalArgumentException("Type argument cannot be null");
        }

        this.enumType = type;
        this.enums    = Arrays.asList(type.getEnumConstants());
    }

    /**
     * Code of e.
     *
     * @param <E>       the type parameter
     * @param enumClass the enum class
     * @param code      the code
     * @return the e
     */
    public static <E extends Enum<?> & BaseEnum> E codeOf(Class<E> enumClass, int code) {
        E[] enumCodes = enumClass.getEnumConstants();

        for (E e : enumCodes) {
            if (e.getValue() == code) {
                return e;
            }
        }

        return null;
    }
}
