package com.cf.cs.database.config;

import com.cf.cs.base.config.CommonConfigure;
import com.mybatisflex.core.audit.AuditManager;
import com.mybatisflex.core.audit.ConsoleMessageCollector;
import com.mybatisflex.core.audit.MessageCollector;
import com.mybatisflex.core.keygen.KeyGeneratorFactory;
import com.mybatisflex.core.logicdelete.LogicDeleteProcessor;
import com.mybatisflex.core.logicdelete.impl.DateTimeLogicDeleteProcessor;
import jakarta.annotation.PostConstruct;
import jakarta.annotation.Resource;
import org.mybatis.spring.annotation.MapperScan;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

/**
 * The type Mybatis flex configure.
 *
 * @author xajhuang @163.com
 */
@Configuration
@MapperScan(value = {"com.cf.cs.database.mapper"})
public class MybatisFlexConfigure {
    @Resource
    private CommonConfigure configure;

    @PostConstruct
    private void initGlobalValue() {
        KeyGeneratorFactory.register("UUID", new UuidKeyGenerator());

        if (configure.isShowSqlCommand()) {
            //开启审计功能
            AuditManager.setAuditEnable(true);

            //设置 SQL 审计收集器
            MessageCollector collector = new ConsoleMessageCollector();
            AuditManager.setMessageCollector(collector);
        }
    }

    /**
     * Logic delete processor logic delete processor.
     *
     * @return the logic delete processor
     */
    @Bean
    public LogicDeleteProcessor logicDeleteProcessor(){
        return new DateTimeLogicDeleteProcessor();
    }
}
