package com.cf.cs.database.service;

import com.cf.cs.base.annotation.OperationLogAnnotation;
import com.cf.cs.base.common.ErrorCode;
import com.cf.cs.database.pojo.entity.OperationLog;
import com.mybatisflex.core.paginate.Page;
import com.mybatisflex.core.service.IService;
import jakarta.servlet.http.HttpServletRequest;

import java.util.List;

/**
 * 系统操作日志 服务层。
 *
 * @author mybatis -flex-helper automatic generation
 * @since 1.0
 */
public interface OperationLogDataBaseService extends IService<OperationLog> {
    /**
     * System operation log.
     *
     * @param call       the call
     * @param request    the request
     * @param result     the result
     * @param annotation the annotation
     * @param errorCode  the error code
     */
    void systemOperationLog(String call, HttpServletRequest request, Object result, OperationLogAnnotation annotation, ErrorCode errorCode);

    /**
     * System operation log.
     *
     * @param call      the call
     * @param request   the request
     * @param result    the result
     * @param module    the module
     * @param optType   the opt type
     * @param desc      the desc
     * @param errorCode the error code
     */
    void systemOperationLog(String call,
                            HttpServletRequest request,
                            Object result,
                            String module,
                            String optType,
                            String desc,
                            ErrorCode errorCode);

    /**
     * Security operation log.
     *
     * @param request   the request
     * @param result    the result
     * @param errorCode the error code
     * @param readme    the readme
     */
    void securityOperationLog(HttpServletRequest request, Object result, ErrorCode errorCode, String readme);

    /**
     * Gets system operation summary.
     *
     * @param pageNumber the page number
     * @param pageSize   the page size
     * @param totalSize  the total size
     * @param userName   the username
     * @return the system operation summary
     */
    Page<OperationLog> getSystemOperationSummary(Long pageNumber, Long pageSize, Long totalSize, List<String> userName);

    /**
     * Gets system operation details.
     *
     * @param operationId the operation id
     * @return the system operation details
     */
    List<OperationLog> getSystemOperationDetails(List<Long> operationId);
}