package com.cf.cs.integratetest.controller;

import com.cf.cs.base.common.ErrorCode;
import com.cf.cs.integratetest.common.TestBaseAuthentication;
import com.cf.cs.protocol.pojo.dto.OperationLogDetailsReq;
import com.cf.cs.protocol.pojo.dto.OperationLogReq;
import com.cf.cs.protocol.pojo.vo.BasePageResultResp;
import com.cf.cs.protocol.pojo.vo.OperationLogDetailsResp;
import com.cf.cs.protocol.pojo.vo.OptLogSummaryResp;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.MethodOrderer;
import org.junit.jupiter.api.Order;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.TestInstance;
import org.junit.jupiter.api.TestMethodOrder;
import org.junit.jupiter.api.extension.ExtendWith;
import org.springframework.test.context.junit.jupiter.SpringExtension;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.RequestMethod;

import java.util.ArrayList;
import java.util.List;

@ExtendWith({SpringExtension.class})
@Transactional
@TestInstance(TestInstance.Lifecycle.PER_CLASS)
@TestMethodOrder(MethodOrderer.OrderAnnotation.class)
@SuppressWarnings("java:S5786")
public class OperationLogApiTest extends TestBaseAuthentication {
    private final List<Long> optIdArray = new ArrayList<>();

    @Test
    @Order(1)
    @DisplayName("获取操作日志摘要(分页)")
    void testGetSummary() throws Exception {
        final long pageSize   = 10L;
        final long pageNumber = 1L;

        OperationLogReq req = new OperationLogReq();
        req.setPageNumber(pageNumber);
        req.setPageSize(pageSize);
        req.setTotalSize(-1L);

        Object obj = performanceRestful(RequestMethod.POST, req, "/api/operation/summary",
                                        new Class[] {BasePageResultResp.class, OptLogSummaryResp.class});
        Assertions.assertNotNull(obj);
        BasePageResultResp<?> resp = (BasePageResultResp<?>) obj;
        AssertValidCommonResp(resp);

        Assertions.assertNotNull(resp.getItems());
        Assertions.assertFalse(resp.getItems().getItems().isEmpty());
        Assertions.assertEquals(resp.getItems().getPageSize(), pageSize);
        Assertions.assertEquals(resp.getItems().getPageNumber(), pageNumber);
        Assertions.assertTrue(resp.getItems().getTotalPage() > 0);
        Assertions.assertTrue(resp.getItems().getTotalRow() > 0);

        List<?> items = resp.getItems().getItems();

        for (Object o : items) {
            Assertions.assertNotNull(o);
        }

        resp.getItems().getItems().forEach(k -> {
            Assertions.assertInstanceOf(OptLogSummaryResp.class, k);
            OptLogSummaryResp o = (OptLogSummaryResp) k;
            Assertions.assertNotNull(o);
            Assertions.assertNotNull(o.getId());
            Assertions.assertNotNull(o.getOperationTime());
            AssertValidString(o.getModule());
            AssertValidString(o.getOperationType());
            AssertValidString(o.getOperationStatus());
            AssertValidString(o.getDescription());
            AssertValidString(o.getRequestIp());
            AssertValidString(o.getHttpMethod());
            AssertValidString(o.getHttpPath());

            optIdArray.add(o.getId());
        });
    }

    @Test
    @Order(2)
    @DisplayName("获取操作日志详情")
    void testGetDetails() throws Exception {
        Assertions.assertFalse(optIdArray.isEmpty());

        OperationLogDetailsReq req = new OperationLogDetailsReq(optIdArray);

        Object obj = performanceRestful(RequestMethod.POST, req, "/api/operation/details", new Class[] {OperationLogDetailsResp.class});
        Assertions.assertNotNull(obj);
        OperationLogDetailsResp resp = (OperationLogDetailsResp) obj;
        AssertValidCommonResp(resp);
        Assertions.assertNotNull(resp.getOperationLog());
        Assertions.assertFalse(resp.getOperationLog().isEmpty());

        resp.getOperationLog().forEach(k -> {
            Assertions.assertEquals(k.getStatus(), ErrorCode.ERR_OK.getCode());
            Assertions.assertNotNull(k.getRequest());
            AssertValidString(k.getResult());
            AssertValidString(k.getRequestHeaders());
            Assertions.assertNotNull(k.getId());
        });
    }
}
