package com.cf.cs.protocol.crypto;

import com.cf.cs.base.common.ProtoCryptoType;
import com.cf.cs.crypto.annotation.EncryptionProtocol;
import com.cf.cs.protocol.config.ProtocolConfigure;
import com.cf.cs.protocol.pojo.vo.ProtocolResp;
import com.cf.cs.protocol.service.ProtocolSecurityService;
import jakarta.annotation.Resource;
import lombok.extern.slf4j.Slf4j;
import org.jetbrains.annotations.NotNull;
import org.springframework.core.MethodParameter;
import org.springframework.http.MediaType;
import org.springframework.http.converter.HttpMessageConverter;
import org.springframework.http.server.ServerHttpRequest;
import org.springframework.http.server.ServerHttpResponse;
import org.springframework.web.bind.annotation.RestControllerAdvice;
import org.springframework.web.servlet.mvc.method.annotation.ResponseBodyAdvice;

import java.util.Objects;


/**
 * The type Response protocol security.
 *
 * @author xajhuang @163.com
 */
@Slf4j
@RestControllerAdvice
public class ResponseProtocolSecurity implements ResponseBodyAdvice<Object> {

    @Resource
    private ProtocolSecurityService protocolSecurityService;

    @Resource
    private ProtocolConfigure protocolConfigure;

    @Override
    public boolean supports(@NotNull MethodParameter methodParameter,
                            @NotNull Class<? extends HttpMessageConverter<?>> aClass) {
        return methodParameter.getContainingClass().isAnnotationPresent(EncryptionProtocol.class)
                || methodParameter.hasMethodAnnotation(EncryptionProtocol.class);
    }

    @Override
    @NotNull
    public Object beforeBodyWrite(Object o,
                                  @NotNull MethodParameter methodParameter,
                                  @NotNull MediaType mediaType,
                                  @NotNull Class<? extends HttpMessageConverter<?>> aClass,
                                  @NotNull ServerHttpRequest serverHttpRequest,
                                  @NotNull ServerHttpResponse serverHttpResponse) {
        if (Objects.equals(protocolConfigure.getCryptoType(), ProtoCryptoType.CRYPTO_NONE.getValue())) {
            if (o instanceof ProtocolResp) {
                serverHttpResponse.setStatusCode(org.springframework.http.HttpStatus.valueOf(((ProtocolResp<?>) o).getCode()));
            }

            return o;
        } else {
            ProtocolResp<String> rspInfo = protocolSecurityService.encryptProtocol(o, protocolConfigure.getCryptoType());
            serverHttpResponse.setStatusCode(org.springframework.http.HttpStatus.valueOf(rspInfo.getCode()));
            return rspInfo;
        }
    }
}
