package com.cf.cs.protocol.pojo.dto;

import com.cf.cs.protocol.validation.group.ValidGroups;
import com.cf.cs.protocol.validation.valids.ValidPageSize;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.swagger.v3.oas.annotations.media.Schema;
import jakarta.validation.constraints.Max;
import jakarta.validation.constraints.Min;
import jakarta.validation.constraints.NotNull;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;

/**
 * The type Base paged req.
 *
 * @author xajhuang @163.com
 */
@Data
@NoArgsConstructor
@AllArgsConstructor
@JsonInclude(JsonInclude.Include.NON_NULL)
@Schema(name = "BasePagedReq", description = "分页请求基础参数")
public class BasePagedReq {
    @Schema(description = "分页号，最小值为1")
    @NotNull(message = "pageNumber 必须指定分页配置", groups = ValidGroups.BasePagedReqValid.class)
    @Min(value = 1, message = "pageNumber 最小值为1", groups = ValidGroups.BasePagedReqValid.class)
    private Long pageNumber;

    @Schema(description = "分页大小，最小值为5， 最大值100， 取值必须为5的整数倍")
    @NotNull(message = "pageSize 必须指定分页配置", groups = ValidGroups.BasePagedReqValid.class)
    @ValidPageSize(message = "pageSize 取值必须为 5 的整数倍", groups = ValidGroups.BasePagedReqValid.class)
    @Min(value = 5, message = "pageSize 最小值为5", groups = ValidGroups.BasePagedReqValid.class)
    @Max(value = 100, message = "pageSize 最大值为100", groups = ValidGroups.BasePagedReqValid.class)
    private Long pageSize;

    @Schema(description = "数据总数，未知时可以为空或者小于0， 存在时可以加快后端数据库查询速度")
    private Long totalSize;
}
