package com.cf.cs.protocol.pojo.dto;

import com.cf.cs.base.common.ConstValue;
import com.cf.cs.protocol.validation.group.ValidGroups;
import com.fasterxml.jackson.annotation.JsonInclude;
import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.Pattern;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.hibernate.validator.constraints.Length;

/**
 * The type Login req.
 *
 * @author xajhuang @163.com
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@JsonInclude(JsonInclude.Include.NON_NULL)
public class LoginReq {
    @NotBlank(message = "username 用户名不能为空", groups = ValidGroups.LogoutReqValid.class)
    @Pattern(regexp = ConstValue.UN_EXPECT_REGEX_CHARS,
             flags = Pattern.Flag.CASE_INSENSITIVE,
             message = "username 用户名存在非法字符串",
             groups = ValidGroups.LogoutReqValid.class)
    private String username;

    /**
     * The Password.
     */
    @NotBlank(message = "password 密码不能为空", groups = ValidGroups.LoginReqValid.class)
    @Length(min = 32, max = 64,
            message = "password 密码长度必须为SHA256编码后的长度",
            groups = ValidGroups.LoginReqValid.class)
    @Pattern(regexp = ConstValue.UN_EXPECT_REGEX_CHARS,
             flags = Pattern.Flag.CASE_INSENSITIVE,
             message = "password 密码存在非法字符串",
             groups = ValidGroups.LoginReqValid.class)
    private String password;
}
