package com.cf.cs.protocol.pojo.dto;

import com.cf.cs.base.common.ConstValue;
import com.cf.cs.protocol.validation.group.ValidGroups;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.swagger.v3.oas.annotations.media.Schema;
import jakarta.validation.constraints.Min;
import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.NotNull;
import jakarta.validation.constraints.Pattern;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.hibernate.validator.constraints.Length;

/**
 * The type Register user req.
 *
 * @author xajhuang @163.com
 */
@Data
@NoArgsConstructor
@AllArgsConstructor
@JsonInclude(JsonInclude.Include.NON_NULL)
public class RegisterUserReq {
    @Schema(description = "用户名")
    @NotBlank(message = "username 用户名不能为空", groups = ValidGroups.UserReqValid.class)
    @Pattern(regexp = ConstValue.UN_EXPECT_REGEX_CHARS,
             flags = Pattern.Flag.CASE_INSENSITIVE,
             message = "username 用户名存在非法字符串",
             groups = ValidGroups.UserReqValid.class)
    private String username;

    @Schema(description = "密码")
    @NotBlank(message = "password 密码不能为空", groups = ValidGroups.UserReqValid.class)
    @Length(min = 32, max = 64,
            message = "password 密码长度必须为SHA256编码后的长度",
            groups = ValidGroups.UserReqValid.class)
    @Pattern(regexp = ConstValue.UN_EXPECT_REGEX_CHARS,
             flags = Pattern.Flag.CASE_INSENSITIVE,
             message = "password 密码存在非法字符串",
             groups = ValidGroups.UserReqValid.class)
    private String password;

    @Schema(description = "用户组ID")
    @NotNull(message = "roleId 用户组ID不能为空", groups = ValidGroups.UserReqValid.class)
    @Min(value = 2, message = "roleId 用户组ID最小取值为2", groups = ValidGroups.UserReqValid.class)
    private Long roleId;
}
