package com.cf.cs.protocol.pojo.po;

import com.cf.cs.base.common.ErrorCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;

/**
 * The type Res operation status.
 *
 * @author xajhuang @163.com
 */
@Schema(name = "资源操作结果")
@EqualsAndHashCode(callSuper = true)
@NoArgsConstructor
@AllArgsConstructor
@Data
@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonPropertyOrder({"rid", "path", "resTypeId", "httpMethod", "status", "message"})
public class ResOperationStatus extends BaseRespStatus {
    @Schema(description = "资源id")
    private String rid;

    @Schema(description = "资源URL")
    private String path;

    @Schema(description = "资源类型ID")
    private Integer resTypeId;

    @Schema(description = "资源 HTTP 请求方法")
    private String httpMethod;

    /**
     * Instantiates a new Res operation status.
     *
     * @param rid       the rid
     * @param errorCode the error code
     */
    public ResOperationStatus(String rid, ErrorCode errorCode) {
        this.rid        = rid;
        this.path       = null;
        this.httpMethod = null;
        this.resTypeId  = null;
        this.setStatus(errorCode.getCode());
        this.setMessage(new String[] {errorCode.getDescription()});
    }

    /**
     * Instantiates a new Res operation status.
     *
     * @param path       the path
     * @param httpMethod the http method
     * @param resTypeId  the res type id
     * @param errorCode  the error code
     */
    public ResOperationStatus(String path, String httpMethod, Integer resTypeId, ErrorCode errorCode) {
        this.rid        = null;
        this.path       = path;
        this.httpMethod = httpMethod;
        this.resTypeId  = resTypeId;
        this.setStatus(errorCode.getCode());
        this.setMessage(new String[] {errorCode.getDescription()});
    }

    /**
     * Instantiates a new Res operation status.
     *
     * @param rid        the rid
     * @param path       the path
     * @param httpMethod the http method
     * @param resTypeId  the res type id
     * @param errorCode  the error code
     */
    public ResOperationStatus(String rid, String path, String httpMethod, Integer resTypeId, ErrorCode errorCode) {
        this.rid        = rid;
        this.path       = path;
        this.httpMethod = httpMethod;
        this.resTypeId  = resTypeId;
        this.setStatus(errorCode.getCode());
        this.setMessage(new String[] {errorCode.getDescription()});
    }
}
