package com.cf.cs.protocol.pojo.po;

import com.cf.cs.protocol.validation.group.ValidGroups;
import com.cf.cs.protocol.validation.valids.ValidHttpMethod;
import io.swagger.v3.oas.annotations.media.Schema;
import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.NotNull;
import jakarta.validation.constraints.Size;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.util.List;

/**
 * The type Resource info.
 *
 * @author xajhuang @163.com
 */
@Schema(name = "资源信息")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class ResourceInfo {
    @Schema(description = "资源路径")
    @NotNull(message = "path 资源 URL 不能为 NULL", groups = ValidGroups.ResourceInfoValid.class)
    @NotBlank(message = "path 资源 URL 不能为空字符串", groups = ValidGroups.ResourceInfoValid.class)
    private String path;

    @Schema(description = "资源名称")
    @NotNull(message = "name 资源名称不能为 NULL", groups = ValidGroups.ResourceInfoValid.class)
    @NotBlank(message = "name 资源名称不能为空字符串", groups = ValidGroups.ResourceInfoValid.class)
    private String name;

    @Schema(description = "资源类型名称")
    @NotNull(message = "resTypeId 资源名称不能为 NULL", groups = ValidGroups.ResourceInfoValid.class)
    private Integer resTypeId;

    @Schema(description = "HTTP 方法")
    @NotNull(message = "HttpMethod 方法名称不能为 NULL", groups = ValidGroups.ResourceInfoValid.class)
    @Size(min = 1, max = 8, message = "HttpMethod HTTP 方法名称不能为空", groups = ValidGroups.ResourceInfoValid.class)
    @ValidHttpMethod(groups = ValidGroups.ResourceInfoValid.class)
    private List<String> httpMethod;
}
