package com.cf.cs.protocol.service;

import com.cf.cs.protocol.crypto.DecryptRequestProtocol;
import com.cf.cs.protocol.pojo.vo.ProtocolResp;
import com.fasterxml.jackson.core.JsonProcessingException;
import org.springframework.http.HttpInputMessage;

import java.io.IOException;

/**
 * The interface Protocol security service.
 *
 * @author xajhuang @163.com
 */
public interface ProtocolSecurityService {
    /**
     * Decrypt protocol string.
     *
     * @param ciphertext the ciphertext
     * @return the string
     * @throws JsonProcessingException the json processing exception
     */
    String decryptProtocol(String ciphertext) throws JsonProcessingException;

    /**
     * Decrypt protocol decrypt request protocol.
     *
     * @param httpInputMessage the http input message
     * @return the decrypt request protocol
     * @throws IOException the io exception
     */
    DecryptRequestProtocol decryptProtocol(HttpInputMessage httpInputMessage) throws IOException;

    /**
     * Encrypt protocol string.
     *
     * @param plainText  the plain text
     * @param cryptoType the crypto type
     * @return the string
     */
    String encryptProtocolString(String plainText, int cryptoType);

    /**
     * Encrypt protocol protocol resp.
     *
     * @param orgProtocol the org protocol
     * @param cryptoType  the crypto type
     * @return the protocol resp
     */
    ProtocolResp<String> encryptProtocol(Object orgProtocol, int cryptoType);
}
