package com.cf.cs.restful.controller;

import com.cf.cs.base.annotation.OperationLogAnnotation;
import com.cf.cs.crypto.annotation.EncryptionProtocol;
import com.cf.cs.protocol.pojo.vo.GetHwInfoResp;
import com.cf.cs.protocol.pojo.vo.GetOsInfoResp;
import com.cf.cs.protocol.pojo.vo.GetProcessorInfoResp;
import com.cf.cs.protocol.pojo.vo.ProtocolResp;
import com.cf.cs.restful.service.SystemInfoService;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.annotation.Resource;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.sql.Timestamp;

/**
 * The type System info api.
 *
 * @author xajhuang @163.com
 */
@RestController
@Slf4j
@Tag(name = "系统信息接口")
@RequestMapping(value = "/api/systemInfo")
public class SystemInfoApi {
    @Resource
    private SystemInfoService systemInfoService;

    /**
     * Gets os info.
     *
     * @return the os info
     */
    @GetMapping("/osInfo")
    @EncryptionProtocol
    @OperationLogAnnotation(OperationModule = "系统信息模块", OperationType = "读取", OperationDesc = "获取当前操作系统信息")
    public ProtocolResp<GetOsInfoResp> getOsInfo() {
        return ProtocolResp.result(GetOsInfoResp.builder()
                                                .os(systemInfoService.getOsName())
                                                .bootTime(new Timestamp(systemInfoService.getOsBootTimeStamp()))
                                                .build());
    }

    /**
     * Gets processor info.
     *
     * @return the processor info
     */
    @GetMapping("/processorInfo")
    @EncryptionProtocol
    @OperationLogAnnotation(OperationModule = "系统信息模块", OperationType = "读取", OperationDesc = "获取当前处理器信息")
    public ProtocolResp<GetProcessorInfoResp> getProcessorInfo() {
        return ProtocolResp.result(GetProcessorInfoResp.builder().cpuInfo(systemInfoService.getProcessInfo()).build());
    }

    /**
     * Gets hw info.
     *
     * @return the hw info
     */
    @GetMapping("/hwInfo")
    @EncryptionProtocol
    @OperationLogAnnotation(OperationModule = "系统信息模块", OperationType = "读取", OperationDesc = "获取系统硬件信息")
    public ProtocolResp<GetHwInfoResp> getHwInfo() {
        return ProtocolResp.result(GetHwInfoResp.builder().hwInfo(systemInfoService.getHardwareInfo()).build());
    }
}
