package com.cf.cs.restful.service;

import com.cf.cs.base.pojo.po.PageResults;
import com.cf.cs.database.pojo.po.UserDictionary;
import com.cf.cs.protocol.pojo.po.DictContent;

import java.util.List;
import java.util.Set;

/**
 * The interface Dictionary service.
 *
 * @author xajhuang @163.com
 */
public interface DictionaryService {
    /**
     * Gets all enum dictionary.
     *
     * @return the all enum dictionary
     */
    Set<String> getAllEnumDictionary();

    /**
     * Gets enum dictionary content.
     *
     * @param dictType the dict type
     * @return the enum dictionary content
     */
    List<DictContent> getEnumDictionaryContent(List<String> dictType);

    /**
     * Add new user dictionary.
     *
     * @param type   the type
     * @param name   the name
     * @param remark the remark
     */
    void addNewUserDictionary(String type, String name, String remark);

    /**
     * Upgrade user dictionary.
     *
     * @param type   the type
     * @param name   the name
     * @param remark the remark
     */
    void upgradeUserDictionary(String type, String name, String remark);

    /**
     * Gets user dictionary.
     *
     * @param pageNumber the page number
     * @param pageSize   the page size
     * @param totalSize  the total size
     * @return the user dictionary
     */
    PageResults<UserDictionary> getUserDictionary(Long pageNumber, Long pageSize, Long totalSize);

    /**
     * Gets user dictionary content.
     *
     * @param dictName the dict name
     * @return the user dictionary content
     */
    List<DictContent> getUserDictionaryContent(List<String> dictName);

    /**
     * Remove user dictionary.
     *
     * @param dictName the dict name
     */
    void removeUserDictionary(String dictName);
}
